@@ -155,6 +155,7 @@ Project::Project(QObject *parent) :
     mSheetCount(0),
     mTmpFile(0),
     mLastTmpFile(0),
+    mNullPrinter("Fake"),
     mPrinter(&mNullPrinter),
     mDoubleSided(true),
     mRotation(NoRotate)
@@ -493,12 +494,17 @@ void Project::setDoubleSided(bool value)
 /************************************************
 
  ************************************************/
-void Project::setPrinter(Printer *value, bool update)
+void Project::setPrinterProfile(Printer *printer, int profile, bool update)
 {
-    if (value)
-        mPrinter = value;
+    if (printer)
+    {
+        mPrinter = printer;
+        mPrinter->setCurrentProfile(profile);
+    }
     else
+    {
         mPrinter = &mNullPrinter;
+    }
 
     if (update)
     {
@@ -718,51 +724,54 @@ void MetaData::addDictItem(QByteArray &out, const QString &key, const QDateTime
 /************************************************
 
  ************************************************/
-void Project::load(const QString &fileName, const QString &title, const QString &options, bool autoRemove)
+void Project::load(const QString &fileName, const QString &title, const QString &options, bool autoRemove, uint count)
 {
-    load(QStringList() << fileName, QStringList() << title, options, autoRemove);
+    load(QStringList() << fileName, QStringList() << title, options, autoRemove, count);
 }
 
 
 /************************************************
 
  ************************************************/
-void Project::load(const QStringList &fileNames, const QString &options, bool autoRemove)
+void Project::load(const QStringList &fileNames, const QString &options, bool autoRemove, uint count)
 {
-    load(fileNames, QStringList(), options, autoRemove);
+    load(fileNames, QStringList(), options, autoRemove, count);
 }
 
 
 /************************************************
 
  ************************************************/
-void Project::load(const QStringList &fileNames, const QStringList &titles, const QString &options, bool autoRemove)
+void Project::load(const QStringList &fileNames, const QStringList &titles, const QString &options, bool autoRemove, uint count)
 {
     stopMerging();
     QStringList errors;
 
     JobList jobs;
-    foreach(QString fileName, fileNames)
+    for (uint i=0; i<count; ++i)
     {
-        ProjectFile file;
-        try
+        foreach(QString fileName, fileNames)
         {
-            file.load(fileName, options);
-            for(int i=0; i<file.jobs().count(); ++i)
+            ProjectFile file;
+            try
             {
-                Job job = file.jobs().at(i);
-                job.setAutoRemove(autoRemove);
-                if (i<titles.count())
-                    job.setTitle(titles.at(i));
+                file.load(fileName, options);
+                for(int i=0; i<file.jobs().count(); ++i)
+                {
+                    Job job = file.jobs().at(i);
+                    job.setAutoRemove(autoRemove);
+                    if (i<titles.count())
+                        job.setTitle(titles.at(i));
 
-                jobs << job;
+                    jobs << job;
+                }
+
+                project->setMetadata(file.metaData());
+            }
+            catch (const QString &err)
+            {
+                errors << err;
             }
-
-            project->setMetadata(file.metaData());
-        }
-        catch (const QString &err)
-        {
-            errors << err;
         }
     }
 
