@@ -40,6 +40,7 @@
 #include "configdialog/configdialog.h"
 #include "boomagatypes.h"
 #include "export/exporttopdf.h"
+#include "printdialog/printdialog.h"
 
 #include <math.h>
 #include <QRadioButton>
@@ -69,13 +70,8 @@ MainWindow::MainWindow(QWidget *parent):
 
     setStyleSheet("QListView::item { padding: 2px;}");
 
-    foreach(Printer *printer, Printer::availablePrinters())
-    {
-        ui->printersCbx->addPrinter(printer);
-    }
-    ui->printersCbx->insertSeparator(99999);
     mExportPrinter = new ExportToPDFPrinter();
-    ui->printersCbx->addPrinter(mExportPrinter);
+    fillPrintersCombo();
 
     initStatusBar();
     initActions();
@@ -110,7 +106,7 @@ MainWindow::MainWindow(QWidget *parent):
 
 
     loadSettings();
-    switchPrinter();
+    switchPrinterProfile();
     updateWidgets();
     updateWidgets();
 
@@ -141,8 +137,8 @@ MainWindow::MainWindow(QWidget *parent):
     connect(ui->jobsView, SIGNAL(jobSelected(Job)),
             this, SLOT(switchToJob(Job)));
 
-    connect(ui->printersCbx, SIGNAL(activated(int)),
-            this, SLOT(switchPrinter()));
+    connect(ui->printersCombo, SIGNAL(activated(int)),
+            this, SLOT(switchPrinterProfile()));
 
     connect(project, SIGNAL(changed()),
             this, SLOT(updateWidgets()));
@@ -183,6 +179,41 @@ MainWindow::~MainWindow()
 }
 
 
+/************************************************
+ *
+ ************************************************/
+void MainWindow::fillPrintersCombo()
+{
+    PrintersComboBox *combo = ui->printersCombo;
+
+    Printer *prevPrinter = combo->currentPrinter();
+    int prevProfile = combo->currentProfile();
+
+    combo->setUpdatesEnabled(false);
+    combo->clear();
+
+    foreach(Printer *printer, Printer::availablePrinters())
+    {
+        combo->addPrinter(printer);
+    }
+
+    combo->insertSeparator(99999);
+    combo->addPrinter(mExportPrinter);
+
+    int index = combo->findItem(prevPrinter, prevProfile);
+
+    if (index < 0)
+        index = combo->findItem(prevPrinter, 0);
+
+    if (index < 0)
+        index = combo->findFirstProfile();
+
+
+    combo->setCurrentIndex(index);
+    ui->printersCombo->setUpdatesEnabled(true);
+}
+
+
 /************************************************
 
  ************************************************/
@@ -230,10 +261,20 @@ void MainWindow::loadSettings()
     restoreGeometry(settings->value(Settings::MainWindow_Geometry).toByteArray());
     restoreState(settings->value(Settings::MainWindow_State).toByteArray());
 
+    Printer *currentPrinter = Printer::printerByName(settings->value(Settings::Printer).toString());
+    if (!currentPrinter)
+    {
+        QList<Printer*> pl = Printer::availablePrinters();
+        if (!pl.isEmpty())
+            currentPrinter = pl.first();
+    }
 
-    ui->printersCbx->setCurrentPrinter(settings->value(Settings::Printer).toString());
-    if (ui->printersCbx->currentIndex() < 0)
-        ui->printersCbx->setCurrentIndex(0);
+    if (!currentPrinter)
+        currentPrinter = Printer::nullPrinter();
+
+    ui->printersCombo->setCurrentPrinterProfile(currentPrinter->name(), currentPrinter->currentProfile());
+    if (ui->printersCombo->currentIndex() < 1)
+        ui->printersCombo->setCurrentIndex(ui->printersCombo->findFirstProfile());
 
     QString layoutId = settings->value(Settings::Layout).toString();
 
@@ -258,13 +299,16 @@ void MainWindow::saveSettings()
     settings->setValue(Settings::MainWindow_Geometry, saveGeometry());
     settings->setValue(Settings::MainWindow_State, saveState());
 
-    Printer *printer = ui->printersCbx->currentPrinter();
+    Printer *printer = ui->printersCombo->currentPrinter();
     if (printer)
-        settings->setValue(Settings::Printer, printer->printerName());
+        settings->setValue(Settings::Printer, printer->name());
 
     settings->setValue(Settings::Layout, project->layout()->id());
     settings->setValue(Settings::DoubleSided, project->doubleSided());
 
+    if (project->printer() != Printer::nullPrinter())
+        project->printer()->saveSettings();
+
     settings->sync();
 }
 
@@ -285,6 +329,12 @@ void MainWindow::initActions()
     connect(act, SIGNAL(triggered()),
             this, SLOT(printAndClose()));
 
+    act = ui->actionPrintWithOptions;
+    act->setIcon(Icon::icon(Icon::Print));
+    connect(act, SIGNAL(triggered()),
+            this, SLOT(printWithOptions()));
+
+
     act = ui->actionExit;
     connect(act, SIGNAL(triggered()),
             this, SLOT(close()));
@@ -404,7 +454,7 @@ void MainWindow::updateWidgets()
         mStatusBarCurrentSheetLabel.clear();
     }
 
-    ui->printerConfigBtn->setEnabled(ui->printersCbx->currentPrinter() != 0);
+    ui->printerConfigBtn->setEnabled(ui->printersCombo->currentPrinter() != 0);
 }
 
 
@@ -413,12 +463,11 @@ void MainWindow::updateWidgets()
  ************************************************/
 void MainWindow::showPrinterSettingsDialog()
 {
-    Printer *printer = ui->printersCbx->currentPrinter();
+    Printer *printer = ui->printersCombo->currentPrinter();
     if (printer)
     {
-        PrinterSettings *dialog = PrinterSettings::create(printer);
+        PrinterSettings *dialog = PrinterSettings::execute(printer);
         connect(dialog, SIGNAL(accepted()), this, SLOT(applyPrinterSettings()));
-        dialog->show();
     }
 }
 
@@ -429,7 +478,8 @@ void MainWindow::showPrinterSettingsDialog()
 void MainWindow::applyPrinterSettings()
 {
     project->printer()->saveSettings();
-    switchPrinter();
+    fillPrintersCombo();
+    switchPrinterProfile();
 }
 
 
@@ -449,9 +499,10 @@ void MainWindow::switchLayout()
 /************************************************
 
  ************************************************/
-void MainWindow::switchPrinter()
+void MainWindow::switchPrinterProfile()
 {
-    project->setPrinter(ui->printersCbx->currentPrinter());
+    project->setPrinterProfile(ui->printersCombo->currentPrinter(),
+                               ui->printersCombo->currentProfile());
 }
 
 
@@ -495,7 +546,7 @@ QMessageBox *MainWindow::showPrintDialog(const QString &text)
 /************************************************
 
  ************************************************/
-bool MainWindow::print()
+bool MainWindow::print(uint count)
 {
     struct Keeper
     {
@@ -583,11 +634,11 @@ bool MainWindow::print()
 
              if (showDialog && !keeper.sheets_2.count())
              {
-                 infoDialog = showPrintDialog(tr("Print the all pages on %1.").arg(project->printer()->printerName()));
+                 infoDialog = showPrintDialog(tr("Print the all pages on %1.").arg(project->printer()->name()));
              }
 
 
-             res = project->printer()->print(keeper.sheets_1, "", false, 1);
+             res = project->printer()->print(keeper.sheets_1, "", false, count);
              if (!res)
              {
                  delete(infoDialog);
@@ -605,7 +656,7 @@ bool MainWindow::print()
 
              dialog.setText(tr("Print the odd pages on %1.<p>"
                                "When finished, turn the pages, insert them into the printer<br>"
-                               "and click the Continue button.").arg(project->printer()->printerName()));
+                               "and click the Continue button.").arg(project->printer()->name()));
 
              dialog.addButton(QMessageBox::Abort);
              QPushButton *btn = dialog.addButton(QMessageBox::Ok);
@@ -634,9 +685,9 @@ bool MainWindow::print()
              }
 
              if (showDialog)
-                infoDialog = showPrintDialog(tr("Print the even pages on %1.").arg(project->printer()->printerName()));
+                infoDialog = showPrintDialog(tr("Print the even pages on %1.").arg(project->printer()->name()));
 
-             res = project->printer()->print(keeper.sheets_2, "", false, 1);
+             res = project->printer()->print(keeper.sheets_2, "", false, count);
              if (!res)
              {
                  delete(infoDialog);
@@ -648,7 +699,7 @@ bool MainWindow::print()
     else //if (split) no
     {
         if (showDialog)
-            infoDialog = showPrintDialog(tr("Print the all pages on %1.").arg(project->printer()->printerName()));
+            infoDialog = showPrintDialog(tr("Print the all pages on %1.").arg(project->printer()->name()));
 
         Project::PagesOrder order;
         if (project->printer()->reverseOrder())
@@ -670,7 +721,7 @@ bool MainWindow::print()
             }
         }
 
-        res = project->printer()->print(keeper.sheets_1, "", project->doubleSided(), 1);
+        res = project->printer()->print(keeper.sheets_1, "", project->doubleSided(), count);
         if (!res)
         {
             delete(infoDialog);
@@ -690,18 +741,32 @@ bool MainWindow::print()
 /************************************************
 
  ************************************************/
-void MainWindow::printAndClose()
+void MainWindow::printAndClose(uint count)
 {
-    if (print())
+    if (print(count))
         QTimer::singleShot(200, this, SLOT(close()));
 }
 
 
+/************************************************
+
+ ************************************************/
+void MainWindow::printWithOptions()
+{
+    PrintDialog dialog;
+    if (dialog.exec())
+    {
+        print(dialog.copies());
+    }
+}
+
+
 /************************************************
 
  ************************************************/
 void MainWindow::showAboutDialog()
 {
+    project->printer()->saveSettings();
     AboutDialog dialog(this);
     dialog.exec();
 
@@ -904,6 +969,13 @@ void MainWindow::showJobViewContextMenu(Job job)
 
     menu->addSeparator();
 
+    act = new JobAction(tr("Clone job..."), job, menu);
+    menu->addAction(act);
+    connect(act, SIGNAL(triggered()),
+            this, SLOT(cloneJob()));
+
+    menu->addSeparator();
+
     act = new JobAction(tr("Delete job"), job, menu);
     menu->addAction(act);
     connect(act, SIGNAL(triggered()),
@@ -1157,6 +1229,29 @@ void MainWindow::showConfigDialog()
 }
 
 
+/************************************************
+
+ ************************************************/
+void MainWindow::cloneJob()
+{
+    JobAction *act = qobject_cast<JobAction*>(sender());
+    if (!act)
+        return;
+
+    bool ok;
+    int cnt = QInputDialog::getInt(this, tr("Clone job"), tr("Number of copies:"), 2, 2, 100, 1, &ok);
+    if (ok)
+    {
+        for (int i=1; i<cnt; ++i)
+        {
+            Job job = act->job().clone();
+            job.setTitle(QString("%1 [ %2 ]").arg(job.title()).arg(i+1));
+            project->addJob(job);
+        }
+    }
+}
+
+
 /************************************************
 
  ************************************************/
@@ -1223,9 +1318,9 @@ void MainWindow::saveAs(const QString &fileName)
 void MainWindow::exportAs()
 {
     Printer *prevPrinter = project->printer();
-    project->setPrinter(mExportPrinter, false);
+    project->setPrinterProfile(mExportPrinter, mExportPrinter->currentProfile(), false);
     print();
-    project->setPrinter(prevPrinter, false);
+    project->setPrinterProfile(prevPrinter, prevPrinter->currentProfile(), false);
 }
 
 
