@@ -149,6 +149,10 @@ Are you sure you want to overwrite it?</source>
         <translation>Soubor s názvem &quot;%1&quot; již existuje.
 Jste si jistý, že jej chcete přepsat?</translation>
     </message>
+    <message>
+        <source> The document&apos;s title.</source>
+        <translation>Název dokumentu.</translation>
+    </message>
 </context>
 <context>
     <name>JobsListView</name>
@@ -210,7 +214,7 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <translation>Tiskárna</translation>
     </message>
     <message>
-        <source>Configure ...</source>
+        <source>Configure...</source>
         <translation>Nastavit...</translation>
     </message>
     <message>
@@ -328,7 +332,7 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <source>Save as ...</source>
+        <source>Save as...</source>
         <translation>Uložit jako...</translation>
     </message>
     <message>
@@ -340,7 +344,7 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <translation>Ctrl+Shift+S</translation>
     </message>
     <message>
-        <source>Open ...</source>
+        <source>Open...</source>
         <translation>Otevřít...</translation>
     </message>
     <message>
@@ -432,6 +436,41 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
+    <message>
+        <source>Clone job...</source>
+        <translation>Klonovat úlohu...</translation>
+    </message>
+    <message>
+        <source>Clone job</source>
+        <translation>Klonovat úlohu</translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation>Počet kopií:</translation>
+    </message>
+    <message>
+        <source>Print with options...</source>
+        <translation>Tisknout s volbami...</translation>
+    </message>
+    <message>
+        <source>Select number of copies before printing.</source>
+        <translation>Vybrat před tiskem počet kopií.</translation>
+    </message>
+    <message>
+        <source>Ctrl+Shift+P</source>
+        <translation>Ctrl+Shift+P</translation>
+    </message>
+</context>
+<context>
+    <name>PrintDialog</name>
+    <message>
+        <source>Print document</source>
+        <translation>Vytisknout dokument</translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation>Počet kopií:</translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -487,6 +526,27 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>Preferences of &quot;%1&quot;</source>
         <translation>Nastavení &quot;%1&quot;</translation>
     </message>
+    <message>
+        <source>Profiles</source>
+        <translation>Profily</translation>
+    </message>
+    <message>
+        <source>+</source>
+        <translation>+</translation>
+    </message>
+    <message>
+        <source>-</source>
+        <translation>-</translation>
+    </message>
+    <message>
+        <source>Reset to default</source>
+        <translation>Obnovit výchozí nastavení</translation>
+    </message>
+    <message>
+        <source>Profile %1</source>
+        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
+        <translation>Profil %1</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -553,6 +613,11 @@ Jste si jistý, že jej chcete přepsat?</translation>
         <source>Untitled</source>
         <translation>Bez názvu</translation>
     </message>
+    <message>
+        <source>Default</source>
+        <comment>Printer profile default name</comment>
+        <translation>Výchozí</translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
