@@ -149,6 +149,10 @@ Are you sure you want to overwrite it?</source>
         <translation>Eine Datei &quot;%1&quot; existiert bereits.
 Sind Sie sicher, dass diese überschrieben werden soll?</translation>
     </message>
+    <message>
+        <source> The document&apos;s title.</source>
+        <translation>Der Titel des Dokuments.</translation>
+    </message>
 </context>
 <context>
     <name>JobsListView</name>
@@ -210,8 +214,8 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <translation>Drucker</translation>
     </message>
     <message>
-        <source>Configure ...</source>
-        <translation>Konfigurieren ...</translation>
+        <source>Configure...</source>
+        <translation>Konfigurieren...</translation>
     </message>
     <message>
         <source>Toolbar</source>
@@ -328,8 +332,8 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <translation>Strg+S</translation>
     </message>
     <message>
-        <source>Save as ...</source>
-        <translation>Speichern unter ...</translation>
+        <source>Save as...</source>
+        <translation>Speichern unter...</translation>
     </message>
     <message>
         <source>Save project under a new name</source>
@@ -340,8 +344,8 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <translation>Strg+Umschalt+S</translation>
     </message>
     <message>
-        <source>Open ...</source>
-        <translation>Öffnen ...</translation>
+        <source>Open...</source>
+        <translation>Öffnen...</translation>
     </message>
     <message>
         <source>Open an existing project</source>
@@ -432,6 +436,41 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <source>Ctrl+E</source>
         <translation>Strg+E</translation>
     </message>
+    <message>
+        <source>Clone job...</source>
+        <translation>Druckauftrag klonen...</translation>
+    </message>
+    <message>
+        <source>Clone job</source>
+        <translation>Druckauftrag klonen</translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation>Anzahl der Kopien:</translation>
+    </message>
+    <message>
+        <source>Print with options...</source>
+        <translation>Mit Optionen drucken...</translation>
+    </message>
+    <message>
+        <source>Select number of copies before printing.</source>
+        <translation>Wählen Sie die Anzahl der Kopien vor dem Drucken aus.</translation>
+    </message>
+    <message>
+        <source>Ctrl+Shift+P</source>
+        <translation>Strg+Umschalt+P</translation>
+    </message>
+</context>
+<context>
+    <name>PrintDialog</name>
+    <message>
+        <source>Print document</source>
+        <translation>Dokument drucken</translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation>Anzahl der Kopien:</translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -487,6 +526,27 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <source>Preferences of &quot;%1&quot;</source>
         <translation>Einstellungen von &quot;%1&quot;</translation>
     </message>
+    <message>
+        <source>Profiles</source>
+        <translation>Profile</translation>
+    </message>
+    <message>
+        <source>+</source>
+        <translation>+</translation>
+    </message>
+    <message>
+        <source>-</source>
+        <translation>-</translation>
+    </message>
+    <message>
+        <source>Reset to default</source>
+        <translation>Auf Standardeinstellung zurücksetzen</translation>
+    </message>
+    <message>
+        <source>Profile %1</source>
+        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
+        <translation>Profil %1</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -553,6 +613,11 @@ Sind Sie sicher, dass diese überschrieben werden soll?</translation>
         <source>Untitled</source>
         <translation>Unbenannt</translation>
     </message>
+    <message>
+        <source>Default</source>
+        <comment>Printer profile default name</comment>
+        <translation>Standard</translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
