@@ -149,6 +149,10 @@ Are you sure you want to overwrite it?</source>
         <translation>Ένα αρχείο με όνομα %1 υπάρχει ήδη.
 Επιθυμείτε σίγουρα την αντικατάστασή του;</translation>
     </message>
+    <message>
+        <source> The document&apos;s title.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>JobsListView</name>
@@ -210,8 +214,8 @@ Are you sure you want to overwrite it?</source>
         <translation>Εκτυπωτής</translation>
     </message>
     <message>
-        <source>Configure ...</source>
-        <translation>Διαμόρφωση ...</translation>
+        <source>Configure...</source>
+        <translation>Διαμόρφωση...</translation>
     </message>
     <message>
         <source>Toolbar</source>
@@ -328,7 +332,7 @@ Are you sure you want to overwrite it?</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Save as ...</source>
+        <source>Save as...</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -340,7 +344,7 @@ Are you sure you want to overwrite it?</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Open ...</source>
+        <source>Open...</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -432,6 +436,41 @@ Are you sure you want to overwrite it?</source>
         <source>Ctrl+E</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Clone job...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Clone job</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Print with options...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Select number of copies before printing.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Ctrl+Shift+P</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>PrintDialog</name>
+    <message>
+        <source>Print document</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -487,6 +526,27 @@ Are you sure you want to overwrite it?</source>
         <source>Preferences of &quot;%1&quot;</source>
         <translation>Προτιμήσεις του «%1»</translation>
     </message>
+    <message>
+        <source>Profiles</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>+</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>-</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Reset to default</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Profile %1</source>
+        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -553,6 +613,11 @@ Are you sure you want to overwrite it?</source>
         <source>Untitled</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Default</source>
+        <comment>Printer profile default name</comment>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Settings</name>
