@@ -149,6 +149,10 @@ Are you sure you want to overwrite it?</source>
         <translation>Un fichier nommé « %1 » existe déjà.
 Êtes-vous sûr de vouloir l&apos;écraser ?</translation>
     </message>
+    <message>
+        <source> The document&apos;s title.</source>
+        <translation>Le titre du document.</translation>
+    </message>
 </context>
 <context>
     <name>JobsListView</name>
@@ -210,7 +214,7 @@ Are you sure you want to overwrite it?</source>
         <translation>Imprimante</translation>
     </message>
     <message>
-        <source>Configure ...</source>
+        <source>Configure...</source>
         <translation>Configurer...</translation>
     </message>
     <message>
@@ -328,7 +332,7 @@ Are you sure you want to overwrite it?</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <source>Save as ...</source>
+        <source>Save as...</source>
         <translation>Enregistrer sous...</translation>
     </message>
     <message>
@@ -340,7 +344,7 @@ Are you sure you want to overwrite it?</source>
         <translation>Ctrl+Maj+S</translation>
     </message>
     <message>
-        <source>Open ...</source>
+        <source>Open...</source>
         <translation>Ouvrir...</translation>
     </message>
     <message>
@@ -432,6 +436,41 @@ Are you sure you want to overwrite it?</source>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
+    <message>
+        <source>Clone job...</source>
+        <translation>Cloner le travail...</translation>
+    </message>
+    <message>
+        <source>Clone job</source>
+        <translation>Cloner le travail</translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation>Nombre de copies :</translation>
+    </message>
+    <message>
+        <source>Print with options...</source>
+        <translation>Imprimer avec des options...</translation>
+    </message>
+    <message>
+        <source>Select number of copies before printing.</source>
+        <translation>Choisir le nombre de copies avant d&apos;imprimer.</translation>
+    </message>
+    <message>
+        <source>Ctrl+Shift+P</source>
+        <translation>Ctrl+Maj+P</translation>
+    </message>
+</context>
+<context>
+    <name>PrintDialog</name>
+    <message>
+        <source>Print document</source>
+        <translation>Imprimer le document</translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation>Nombre de copies :</translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -487,6 +526,27 @@ Are you sure you want to overwrite it?</source>
         <source>Preferences of &quot;%1&quot;</source>
         <translation>Préférences de &quot;%1&quot;</translation>
     </message>
+    <message>
+        <source>Profiles</source>
+        <translation>Profils</translation>
+    </message>
+    <message>
+        <source>+</source>
+        <translation>+</translation>
+    </message>
+    <message>
+        <source>-</source>
+        <translation>-</translation>
+    </message>
+    <message>
+        <source>Reset to default</source>
+        <translation>Réinitialiser à la valeur par défaut</translation>
+    </message>
+    <message>
+        <source>Profile %1</source>
+        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
+        <translation>Profil %1</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -553,6 +613,11 @@ Are you sure you want to overwrite it?</source>
         <source>Untitled</source>
         <translation>Sans titre</translation>
     </message>
+    <message>
+        <source>Default</source>
+        <comment>Printer profile default name</comment>
+        <translation>Valeur par défaut</translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
