@@ -149,6 +149,10 @@ Are you sure you want to overwrite it?</source>
         <translation>Un file con nome &quot;%1&quot; esiste già.
 Sei sicuro di volerlo sovracrivere?</translation>
     </message>
+    <message>
+        <source> The document&apos;s title.</source>
+        <translation>Il titolo del documento.</translation>
+    </message>
 </context>
 <context>
     <name>JobsListView</name>
@@ -210,8 +214,8 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <translation>Stampante</translation>
     </message>
     <message>
-        <source>Configure ...</source>
-        <translation>Configura ...</translation>
+        <source>Configure...</source>
+        <translation>Configura...</translation>
     </message>
     <message>
         <source>Toolbar</source>
@@ -328,8 +332,8 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <source>Save as ...</source>
-        <translation>Salva come ...</translation>
+        <source>Save as...</source>
+        <translation>Salva come...</translation>
     </message>
     <message>
         <source>Save project under a new name</source>
@@ -340,8 +344,8 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <translation>Ctrl+Shift+S</translation>
     </message>
     <message>
-        <source>Open ...</source>
-        <translation>Apri ...</translation>
+        <source>Open...</source>
+        <translation>Apri...</translation>
     </message>
     <message>
         <source>Open an existing project</source>
@@ -432,6 +436,41 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
+    <message>
+        <source>Clone job...</source>
+        <translation>Clonare un lavoro di stampa...</translation>
+    </message>
+    <message>
+        <source>Clone job</source>
+        <translation>Clonare un lavoro di stampa</translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation>Numero di copie:</translation>
+    </message>
+    <message>
+        <source>Print with options...</source>
+        <translation>Stampare con opzioni...</translation>
+    </message>
+    <message>
+        <source>Select number of copies before printing.</source>
+        <translation>Selezionare il numero di copie prima di stampare.</translation>
+    </message>
+    <message>
+        <source>Ctrl+Shift+P</source>
+        <translation>Ctrl+Shift+P</translation>
+    </message>
+</context>
+<context>
+    <name>PrintDialog</name>
+    <message>
+        <source>Print document</source>
+        <translation>Stampare il documento</translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation>Numero di copie:</translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -487,6 +526,27 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>Preferences of &quot;%1&quot;</source>
         <translation>Preferenze di &quot;%1&quot;</translation>
     </message>
+    <message>
+        <source>Profiles</source>
+        <translation>Profili</translation>
+    </message>
+    <message>
+        <source>+</source>
+        <translation>+</translation>
+    </message>
+    <message>
+        <source>-</source>
+        <translation>-</translation>
+    </message>
+    <message>
+        <source>Reset to default</source>
+        <translation>Ripristinare impostazioni predefinite</translation>
+    </message>
+    <message>
+        <source>Profile %1</source>
+        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
+        <translation>Profilo %1</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -553,6 +613,11 @@ Sei sicuro di volerlo sovracrivere?</translation>
         <source>Untitled</source>
         <translation>Senza nome</translation>
     </message>
+    <message>
+        <source>Default</source>
+        <comment>Printer profile default name</comment>
+        <translation>Predefinito</translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
