@@ -149,6 +149,10 @@ Are you sure you want to overwrite it?</source>
         <translation>Файл с именем &quot;%1&quot; уже существует.
 Заменить его?</translation>
     </message>
+    <message>
+        <source> The document&apos;s title.</source>
+        <translation>Заголовок документа.</translation>
+    </message>
 </context>
 <context>
     <name>JobsListView</name>
@@ -210,8 +214,8 @@ Are you sure you want to overwrite it?</source>
         <translation>Принтер</translation>
     </message>
     <message>
-        <source>Configure ...</source>
-        <translation>Настроить ...</translation>
+        <source>Configure...</source>
+        <translation>Настроить...</translation>
     </message>
     <message>
         <source>Toolbar</source>
@@ -328,7 +332,7 @@ Are you sure you want to overwrite it?</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <source>Save as ...</source>
+        <source>Save as...</source>
         <translation>Сохранить как...</translation>
     </message>
     <message>
@@ -340,8 +344,8 @@ Are you sure you want to overwrite it?</source>
         <translation>Ctrl+Shift+S</translation>
     </message>
     <message>
-        <source>Open ...</source>
-        <translation>Открыть ...</translation>
+        <source>Open...</source>
+        <translation>Открыть...</translation>
     </message>
     <message>
         <source>Open an existing project</source>
@@ -422,7 +426,7 @@ Are you sure you want to overwrite it?</source>
     </message>
     <message>
         <source>&amp;Export...</source>
-        <translation>&amp;Экспортировать ...</translation>
+        <translation>&amp;Экспортировать...</translation>
     </message>
     <message>
         <source>Export the project to PDF</source>
@@ -432,6 +436,41 @@ Are you sure you want to overwrite it?</source>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
+    <message>
+        <source>Clone job...</source>
+        <translation>Клонировать задание...</translation>
+    </message>
+    <message>
+        <source>Clone job</source>
+        <translation>Клонирование задания</translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation>Количество копий</translation>
+    </message>
+    <message>
+        <source>Print with options...</source>
+        <translation>Печать с выбором настроек...</translation>
+    </message>
+    <message>
+        <source>Select number of copies before printing.</source>
+        <translation>Выбор количества копий перед печатью.</translation>
+    </message>
+    <message>
+        <source>Ctrl+Shift+P</source>
+        <translation>Ctrl+Shift+P</translation>
+    </message>
+</context>
+<context>
+    <name>PrintDialog</name>
+    <message>
+        <source>Print document</source>
+        <translation>Печать документа</translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation>Количество копий:</translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -487,6 +526,27 @@ Are you sure you want to overwrite it?</source>
         <source>Preferences of &quot;%1&quot;</source>
         <translation>Настройки &quot;%1&quot;</translation>
     </message>
+    <message>
+        <source>Profiles</source>
+        <translation>Профили</translation>
+    </message>
+    <message>
+        <source>+</source>
+        <translation>+</translation>
+    </message>
+    <message>
+        <source>-</source>
+        <translation>-</translation>
+    </message>
+    <message>
+        <source>Reset to default</source>
+        <translation>Сброс</translation>
+    </message>
+    <message>
+        <source>Profile %1</source>
+        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
+        <translation>Профиль %1</translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -553,6 +613,11 @@ Are you sure you want to overwrite it?</source>
         <source>Untitled</source>
         <translation>Без имени</translation>
     </message>
+    <message>
+        <source>Default</source>
+        <comment>Printer profile default name</comment>
+        <translation>По умолчанию</translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
