@@ -148,6 +148,10 @@
 Are you sure you want to overwrite it?</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source> The document&apos;s title.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>JobsListView</name>
@@ -209,7 +213,7 @@ Are you sure you want to overwrite it?</source>
         <translation>Printer</translation>
     </message>
     <message>
-        <source>Configure ...</source>
+        <source>Configure...</source>
         <translation>Sozlash...</translation>
     </message>
     <message>
@@ -327,7 +331,7 @@ Are you sure you want to overwrite it?</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Save as ...</source>
+        <source>Save as...</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -339,7 +343,7 @@ Are you sure you want to overwrite it?</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Open ...</source>
+        <source>Open...</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -431,6 +435,41 @@ Are you sure you want to overwrite it?</source>
         <source>Ctrl+E</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Clone job...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Clone job</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Print with options...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Select number of copies before printing.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Ctrl+Shift+P</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>PrintDialog</name>
+    <message>
+        <source>Print document</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -486,6 +525,27 @@ Are you sure you want to overwrite it?</source>
         <source>Preferences of &quot;%1&quot;</source>
         <translation>&quot;%1&quot; sozlashlari</translation>
     </message>
+    <message>
+        <source>Profiles</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>+</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>-</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Reset to default</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Profile %1</source>
+        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -552,6 +612,11 @@ Are you sure you want to overwrite it?</source>
         <source>Untitled</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Default</source>
+        <comment>Printer profile default name</comment>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Settings</name>
