@@ -150,6 +150,10 @@
 Are you sure you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source> The document&apos;s title.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>JobsListView</name>
@@ -211,7 +215,7 @@ Are you sure you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Configure ...</source>
+        <source>Configure...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -329,7 +333,7 @@ Are you sure you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Save as ...</source>
+        <source>Save as...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -341,7 +345,7 @@ Are you sure you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Open ...</source>
+        <source>Open...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -433,6 +437,41 @@ Are you sure you want to overwrite it?</source>
         <source>Ctrl+E</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Clone job...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clone job</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Print with options...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select number of copies before printing.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+Shift+P</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>PrintDialog</name>
+    <message>
+        <source>Print document</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number of copies:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PrinterSettings</name>
@@ -488,6 +527,27 @@ Are you sure you want to overwrite it?</source>
         <source>Preferences of &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Profiles</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>-</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reset to default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Profile %1</source>
+        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Project</name>
@@ -554,6 +614,11 @@ Are you sure you want to overwrite it?</source>
         <source>Untitled</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Default</source>
+        <comment>Printer profile default name</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
